@@ -117,7 +117,12 @@ class Base(metaclass=ABCMeta):
 
 
 class User(Base):
-    """Object representing a CRIPT user."""
+    """
+    Object representing a CRIPT user.
+
+    Note: A user cannot be created or modified using the SDK.
+          This object is for read-only purposes only.
+    """
 
     node_type = "primary"
     node_name = "User"
@@ -242,14 +247,28 @@ class Citation(Base):
     node_type = "secondary"
     node_name = "Citation"
     list_name = "citations"
+    required = ["reference"]
 
     @beartype
     def __init__(
-        self, reference: Union[Reference, str], method: Union[str, None] = None
+        self,
+        reference: Union[Reference, str] = None,
+        type: Union[str, None] = "reference",
+        notes: Union[str, None] = None,
     ):
         super().__init__()
-        self.method = method
         self.reference = reference
+        self.type = type
+        self.notes = notes
+        validate_required(self)
+
+    @property
+    def type(self):
+        return self._type
+
+    @type.setter
+    def type(self, value):
+        self._type = validate_key("citation-type", value)
 
 
 class Collection(Base):
@@ -595,8 +614,9 @@ class Property(Base):
         component_id: Union[int, None] = None,
         structure: Union[str, None] = None,
         set_id: Union[int, None] = None,
-        data: list[Union[Data, str]] = None,
         conditions: list[Union[Condition, dict]] = None,
+        data: list[Union[Data, str]] = None,
+        citations: list[Union[Citation, dict]] = None,
     ):
         super().__init__()
         self.key = key
@@ -610,8 +630,9 @@ class Property(Base):
         self.component_id = component_id
         self.structure = structure
         self.set_id = set_id
-        self.data = data if data else []
         self.conditions = conditions if conditions else []
+        self.data = data if data else []
+        self.citations = citations if citations else []
         validate_required(self)
 
     @property
@@ -678,6 +699,14 @@ class Property(Base):
     def remove_condition(self, condition: Union[Condition, int]):
         self._remove_node(condition, "conditions")
 
+    @beartype
+    def add_citation(self, citation: Union[Citation, dict]):
+        self._add_node(citation, "citations")
+
+    @beartype
+    def remove_citation(self, citation: Union[Citation, int]):
+        self._remove_node(citation, "citations")
+
 
 class Identifier(Base):
     """
@@ -795,14 +824,10 @@ class Material(Base):
         group: Union[Group, str] = None,
         name: str = None,
         identifiers: list[Union[Identifier, dict]] = None,
-        names: Union[list[str], None] = None,
         components: list[Union[Component, dict]] = None,
-        vendor: Union[str, None] = None,
-        lot_number: Union[str, None] = None,
         keywords: Union[list[str], None] = None,
         process: Union[Base, str, None] = None,  # Needs more specific type check
         properties: list[Union[Property, dict]] = None,
-        citations: list[Union[Citation, dict]] = None,
         notes: Union[str, None] = None,
         public: bool = False,
     ):
@@ -811,15 +836,11 @@ class Material(Base):
         self.uid = None
         self.group = group
         self.name = name
-        self.names = names if names else []
         self.identifiers = identifiers if identifiers else []
         self.components = components if components else []
-        self.vendor = vendor
-        self.lot_number = lot_number
         self.keywords = keywords if keywords else []
         self.process = process
         self.properties = properties if properties else []
-        self.citations = citations if citations else []
         self.notes = notes
         self.public = public
         self.created_at = None
@@ -861,14 +882,6 @@ class Material(Base):
     def remove_property(self, property: Union[Property, int]):
         self._remove_node(property, "properties")
 
-    @beartype
-    def add_citation(self, citation: Union[Citation, dict]):
-        self._add_node(citation, "citations")
-
-    @beartype
-    def remove_citation(self, citation: Union[Citation, int]):
-        self._remove_node(citation, "citations")
-
 
 class Inventory(Base):
     """Object representing a logical grouping of :class:`Material` objects."""
@@ -1019,6 +1032,17 @@ class Process(Base):
                 value[i] = validate_key("process-keyword", value[i])
         self._keywords = value
 
+    @property
+    def equipment(self):
+        return self._equipment
+
+    @equipment.setter
+    def equipment(self, value):
+        if value:
+            for i in range(len(value)):
+                value[i] = validate_key("equipment", value[i])
+        self._equipment = value
+
     @beartype
     def add_prerequisite_process(self, process: Union[Base, dict]):
         self._add_node(process, "prerequisite_processes")
