@@ -14,7 +14,7 @@ from globus_sdk.scopes import ScopeBuilder
 
 from cript import VERSION, NODE_CLASSES
 from cript.nodes import Base, User, File
-from cript.utils import convert_file_size, display_errors
+from cript.utils import get_api_url, convert_file_size, display_errors
 from cript.exceptions import (
     APIAuthError,
     APIRefreshError,
@@ -38,31 +38,32 @@ class API:
     version = VERSION
     keys = None
 
-    def __init__(self, base_url: str = None, api_token: str = None):
+    def __init__(self, host: str = None, token: str = None, tls: bool = True):
         """
         Establishes a session with a CRIPT API endpoint.
 
-        :param base_url: The base URL for the relevant CRIPT instance. (e.g., https://criptapp.org)
-        :param api_token: The API token used for authentication.
+        :param host: The hostname of the relevant CRIPT instance. (e.g., criptapp.org)
+        :param token: The API token used for authentication.
+        :param tls: Indicates whether to use TLS encryption for the API connection.
         """
+        if host is None:
+            host = input("Host: ")
+        if token is None:
+            token = getpass("API Token: ")
+        self.api_url = get_api_url(host, tls)
         self.latest_version = None
         self.user = None
         self.storage_info = None
-        if base_url is None:
-            base_url = input("Base URL: ")
-        if api_token is None:
-            api_token = getpass("API Token: ")
-        self.base_url = base_url.rstrip("/") + "/api"
 
         self.session = requests.Session()
         self.session.headers = {
-            "Authorization": api_token,
+            "Authorization": token,
             "Content-Type": "application/json",
             "Accept": f"application/json; version={self.version}",
         }
 
         # Test API authentication by fetching session info and keys
-        response = self.session.get(f"{self.base_url}/session-info/")
+        response = self.session.get(f"{self.api_url}/session-info/")
         if response.status_code == 200:
             self.latest_version = response.json()["latest_version"]
             self.user = self._create_node(User, response.json()["user_info"])
@@ -73,33 +74,31 @@ class API:
         else:
             raise APIAuthError(display_errors(response.content))
 
-        logger.info(f"Connection to {self.base_url} API was successful!")
+        logger.info(f"Connection to {self.api_url} API was successful!")
 
         # Warn user if an update is required
-        # TODO: (if this makes sense) unify logger.warning and warnings.warn
-        # interfaces. My hunch is that one of them would be sufficient but yet
-        # to test it
         if self.version != self.latest_version:
             warnings.warn(response.json()["version_warning"], stacklevel=2)
 
     def __repr__(self):
-        return f"Connected to {self.base_url}"
+        return f"Connected to {self.api_url}"
 
     def __str__(self):
-        return f"Connected to {self.base_url}"
+        return f"Connected to {self.api_url}"
 
     @beartype
-    def refresh(self, node: Base):
+    def refresh(self, node: Base, max_level: int = 1):
         """
         Overwrite a node's attributes with the latest values from the database.
 
         :param node: The node to refresh.
+        :param max_level: Max depth to recursively generate nested nodes.
         """
         if hasattr(node, "url"):
             if node.url:
                 response = self.session.get(node.url)
                 self._set_node_attributes(node, response.json())
-                self._generate_nodes(node)
+                self._generate_nodes(node, max_level=max_level)
             else:
                 raise APIRefreshError(
                     "Before you can refresh a node, you must either save it or define its URL."
@@ -110,11 +109,12 @@ class API:
             )
 
     @beartype
-    def save(self, node: Base):
+    def save(self, node: Base, max_level: int = 1):
         """
         Create or update a node in the database.
 
         :param node: The node to be saved.
+        :param max_level: Max depth to recursively generate nested nodes.
         """
         if node.node_type == "primary":
             if node.url:
@@ -123,7 +123,7 @@ class API:
             else:
                 # Create a new object via POST
                 response = self.session.post(
-                    url=f"{self.base_url}/{node.slug}/", data=node._to_json()
+                    url=f"{self.api_url}/{node.slug}/", data=node._to_json()
                 )
         else:
             raise APISaveError(
@@ -137,11 +137,11 @@ class API:
                 self._upload_file(file_uid, node)
 
             self._set_node_attributes(node, response.json())
-            self._generate_nodes(node)
+            self._generate_nodes(node, max_level=max_level)
 
             # Update File node source field
             if node.slug == "file":
-                self.refresh(node)
+                self.refresh(node, max_level=max_level)
 
             logger.info(f"{node.node_name} node has been saved to the database.")
 
@@ -229,7 +229,7 @@ class API:
         """
         payload = {"file_uid": file_uid}
         response = self.session.post(
-            url=f"{self.base_url}/globus-stage-download/", data=json.dumps(payload)
+            url=f"{self.api_url}/globus-stage-download/", data=json.dumps(payload)
         )
         if response.status_code != 200:
             raise APIFileDownloadError
@@ -368,7 +368,7 @@ class API:
         """
         payload = {"file_uid": file_uid, "file_checksum": file_checksum}
         response = self.session.post(
-            url=f"{self.base_url}/globus-stage-upload/",
+            url=f"{self.api_url}/globus-stage-upload/",
             data=json.dumps(payload),
         )
         if response.status_code != 200:
@@ -389,7 +389,7 @@ class API:
             "file_checksum": node.checksum,
         }
         response = self.session.post(
-            url=f"{self.base_url}/s3-signed-url/", data=json.dumps(payload)
+            url=f"{self.api_url}/s3-signed-url/", data=json.dumps(payload)
         )
 
         # Upload file
@@ -419,7 +419,7 @@ class API:
             "file_checksum": node.checksum,
         }
         response = self.session.post(
-            url=f"{self.base_url}/s3-multipart-upload/",
+            url=f"{self.api_url}/s3-multipart-upload/",
             data=json.dumps(payload),
         )
         upload_id = json.loads(response.content)["UploadId"]
@@ -442,7 +442,7 @@ class API:
                     "part_number": len(parts) + 1,
                 }
                 response = self.session.post(
-                    url=f"{self.base_url}/s3-signed-url/", data=json.dumps(data)
+                    url=f"{self.api_url}/s3-signed-url/", data=json.dumps(data)
                 )
 
                 # Upload file chunk
@@ -465,7 +465,7 @@ class API:
             "parts": parts,
         }
         response = self.session.post(
-            url=f"{self.base_url}/s3-multipart-upload/",
+            url=f"{self.api_url}/s3-multipart-upload/",
             data=json.dumps(data),
         )
         if response.status_code != 200:
@@ -476,7 +476,7 @@ class API:
         Delete a node in the database and clear it locally.
 
         :param obj: The node to be deleted itself or its class.
-        :param query: (Optional) A dictionary defining the query parameters (e.g., {"name": "NewMaterial"})
+        :param query: A dictionary defining the query parameters (e.g., {"name": "NewMaterial"})
         """
         # Delete with node
         if isinstance(obj, Base):
@@ -495,7 +495,7 @@ class API:
         # Delete with URL
         elif isinstance(obj, str):
             url = obj
-            if self.base_url not in url:
+            if self.api_url not in url:
                 raise APIDeleteError("Invalid URL provided.")
 
         # Delete with search query
@@ -532,7 +532,7 @@ class API:
         Send a query to the API and print the results.
 
         :param node_class: The class of the node type to query for.
-        :param query: (Optional) A dictionary defining the query parameters (e.g., {"name": "NewMaterial"}).
+        :param query: A dictionary defining the query parameters (e.g., {"name": "NewMaterial"}).
         :return: A :class:`JSONPaginator` object containing the results.
         :rtype: cript.session.JSONPaginator
         """
@@ -544,10 +544,10 @@ class API:
         if isinstance(query, dict):
             query_slug = self._generate_query_slug(query)
             response = self.session.get(
-                f"{self.base_url}/{node_class.slug}/?{query_slug}"
+                f"{self.api_url}/{node_class.slug}/?{query_slug}"
             )
         elif query is None:
-            response = self.session.get(f"{self.base_url}/{node_class.slug}/")
+            response = self.session.get(f"{self.api_url}/{node_class.slug}/")
         else:
             raise APISearchError(f"'{query}' is not a valid query.")
 
@@ -584,7 +584,7 @@ class API:
         """
         # Get node with a URL
         if isinstance(obj, str):
-            if self.base_url not in obj:
+            if self.api_url not in obj:
                 raise APIGetError("Please enter a valid node URL.")
             response = self.session.get(obj)
             if response.status_code == 200:
@@ -641,7 +641,7 @@ class API:
             if key == "url":
                 continue
             # Generate primary nodes
-            if isinstance(value, str) and self.base_url in value:
+            if isinstance(value, str) and self.api_url in value:
                 # Check if node already exists in memory
                 local_node = self._get_local_primary_node(value)
                 if local_node:
@@ -664,7 +664,7 @@ class API:
             elif isinstance(value, list):
                 for i in range(len(value)):
                     # Generate primary nodes
-                    if isinstance(value[i], str) and self.base_url in value[i]:
+                    if isinstance(value[i], str) and self.api_url in value[i]:
                         # Check if node already exists in memory
                         local_node = self._get_local_primary_node(value[i])
                         if local_node:
